@@ -2,8 +2,8 @@
 Notation 3 (N3) RDF graph serializer for RDFLib.
 """
 from rdflib.graph import Graph
-from rdflib.namespace import Namespace, OWL
-from rdflib.plugins.serializers.turtle import TurtleSerializer, SUBJECT, OBJECT
+from rdflib.namespace import OWL, Namespace
+from rdflib.plugins.serializers.turtle import OBJECT, SUBJECT, TurtleSerializer
 
 __all__ = ["N3Serializer"]
 
@@ -23,36 +23,6 @@ class N3Serializer(TurtleSerializer):
         super(N3Serializer, self).reset()
         self._stores = {}
 
-    def subjectDone(self, subject):
-        super(N3Serializer, self).subjectDone(subject)
-        if self.parent:
-            self.parent.subjectDone(subject)
-
-    def isDone(self, subject):
-        return super(N3Serializer, self).isDone(subject) and (
-            not self.parent or self.parent.isDone(subject)
-        )
-
-    def startDocument(self):
-        super(N3Serializer, self).startDocument()
-        # if not isinstance(self.store, N3Store):
-        #    return
-        #
-        # all_list = [self.label(var) for var in
-        #        self.store.get_universals(recurse=False)]
-        # all_list.sort()
-        # some_list = [self.label(var) for var in
-        #        self.store.get_existentials(recurse=False)]
-        # some_list.sort()
-        #
-        # for var in all_list:
-        #    self.write('\n'+self.indent()+'@forAll %s. '%var)
-        # for var in some_list:
-        #    self.write('\n'+self.indent()+'@forSome %s. '%var)
-        #
-        # if (len(all_list) + len(some_list)) > 0:
-        #    self.write('\n')
-
     def endDocument(self):
         if not self.parent:
             super(N3Serializer, self).endDocument()
@@ -68,6 +38,9 @@ class N3Serializer(TurtleSerializer):
         if isinstance(triple[0], Graph):
             for t in triple[0]:
                 self.preprocessTriple(t)
+        if isinstance(triple[1], Graph):
+            for t in triple[1]:
+                self.preprocessTriple(t)
         if isinstance(triple[2], Graph):
             for t in triple[2]:
                 self.preprocessTriple(t)
