@@ -4,34 +4,33 @@ SPARQL 1.1 Parser
 based on pyparsing
 """
 
-import sys
 import re
+import sys
 
-from pyparsing import (
-    Literal,
-    Regex,
-    Optional,
-    OneOrMore,
-    ZeroOrMore,
-    Forward,
-    ParseException,
-    Suppress,
-    Combine,
-    restOfLine,
-    Group,
-    ParseResults,
-    delimitedList,
-)
 from pyparsing import CaselessKeyword as Keyword  # watch out :)
+from pyparsing import (
+    Combine,
+    Forward,
+    Group,
+    Literal,
+    OneOrMore,
+    Optional,
+    ParseResults,
+    Regex,
+    Suppress,
+    ZeroOrMore,
+    delimitedList,
+    restOfLine,
+)
+
+import rdflib
+from rdflib.compat import decodeUnicodeEscape
+
+from . import operators as op
+from .parserutils import Comp, Param, ParamList
 
 # from pyparsing import Keyword as CaseSensitiveKeyword
 
-from .parserutils import Comp, Param, ParamList
-
-from . import operators as op
-from rdflib.compat import decodeUnicodeEscape
-
-import rdflib
 
 DEBUG = False
 
@@ -95,7 +94,7 @@ def expandTriples(terms):
         #       "Length of triple-list is not divisible by 3: %d!"%len(res)
 
         # return [tuple(res[i:i+3]) for i in range(len(res)/3)]
-    except:
+    except:  # noqa: E722
         if DEBUG:
             import traceback
 
@@ -227,13 +226,6 @@ PN_LOCAL = Regex(
 )
 
 
-def _hexExpand(match):
-    return chr(int(match.group(0)[1:], 16))
-
-
-PN_LOCAL.setParseAction(lambda x: re.sub("(%s)" % PERCENT_re, _hexExpand, x[0]))
-
-
 # [141] PNAME_LN ::= PNAME_NS PN_LOCAL
 PNAME_LN = PNAME_NS + Param("localname", PN_LOCAL.leaveWhitespace())
 
@@ -1528,7 +1520,7 @@ def expandUnicodeEscapes(q):
     def expand(m):
         try:
             return chr(int(m.group(1), 16))
-        except:
+        except:  # noqa: E722
             raise Exception("Invalid unicode code point: " + m)
 
     return expandUnicodeEscapes_re.sub(expand, q)
@@ -1553,17 +1545,3 @@ def parseUpdate(q):
 
     q = expandUnicodeEscapes(q)
     return UpdateUnit.parseString(q, parseAll=True)[0]
-
-
-if __name__ == "__main__":
-    import sys
-
-    DEBUG = True
-    try:
-        q = Query.parseString(sys.argv[1])
-        print("\nSyntax Tree:\n")
-        print(q)
-    except ParseException as err:
-        print(err.line)
-        print(" " * (err.column - 1) + "^")
-        print(err)
